package de.hft.stuttgart.citydoctor2.connect.edge;


import de.hft.stuttgart.citydoctor2.connect.edge.CppReferenceHandlingBase;
import de.hft.stuttgart.citydoctor2.connect.edge.NativePointerCastException;

public class AutoProSettingsGeneral extends CppReferenceHandlingBase {
	private native long createCppClass(
				boolean printBuildingInfo,
				boolean printStatus,
				boolean printSmallestAngle,
				boolean printNumberOFSmallAngles,
				double smallAngleTolerance,
				boolean printShortestEdge,
				boolean printNumberOfShortEdges,
				double shortEdgesTolerance,
				boolean printVolume,				
				boolean printNumberOfFacesAndVertices				
			)
			throws OutOfMemoryError;

	private native void disposeCppClass(long ptrToCppAutoPro)
			throws NativePointerCastException;


	private boolean printBuildingInfo;
	private boolean printStatus;
	private boolean printSmallestAngle;
	private boolean printNumberOfSmallAngles;
	private double smallAngleTolerance;
	private boolean printShortestEdge;
	private boolean printNumberOfShortEdges;
	private double shortEdgesTolerance;
	private boolean printVolume;
	private boolean printNumberOfFacesAndVertices;

	public AutoProSettingsGeneral() {

		setPrintBuildingInfo(false);
		setPrintStatus(false);
		setPrintSmallestAngle(false);
		setPrintNumberOfSmallAngles(false);
		setSmallAngleTolerance(0.1);
		setPrintShortestEdge(false);
		setPrintNumberOfShortEdges(false);
		setShortEdgesTolerance(0.1);
		setPrintVolume(false);	
		setPrintNumberOfFacesAndVertices(false);

	}

	/**
	 * Creates an C++ feature object
	 * 
	 * @throws IllegalStateException
	 *             Thrown if the encapsulated "long-Pointer" isn't 0
	 * @throws NativeOutOfMemoryException
	 *             If there is no more memory on the native side
	 * 
	 * @see {@link disposeCppObject}
	 * @see de.hft.stuttgart.citydoctor.connect.edGe.CppReferenceHandlingBase#createCppObject()
	 */
	public void createCppObject() throws IllegalStateException,
			OutOfMemoryError {
		if (0L != ptrToCppObject) {
			throw new IllegalStateException(
					"Can't create new C++ object, there is allready one!");
		}
		// Maybe an exception is thrown
		long tmpPointer = createCppClass(
				isPrintBuildingInfo(),
				isPrintStatus(),
				isPrintSmallestAngle(),
				isPrintNumberOfSmallAngles(),
				getSmallAngleTolerance(),
				isPrintShortestEdge(),
				isPrintNumberOfShortEdges(),
				getShortEdgesTolerance(),
				isPrintVolume(),
				isPrintNumberOfFacesAndVertices()
				);
		ptrToCppObject = tmpPointer;
	}

	@Override
	public void disposeCppObject() throws NativePointerCastException {
		if (0L != ptrToCppObject) {
			disposeCppClass(ptrToCppObject);
			ptrToCppObject = 0L;
		}
	}

	public void setPrintBuildingInfo(boolean printBuildingInfo) {
		this.printBuildingInfo = printBuildingInfo;
	}

	public void setPrintStatus(boolean printStatus) {
		this.printStatus = printStatus;
	}	
	
	public void setPrintSmallestAngle(boolean printSmallestAngle) {
		this.printSmallestAngle = printSmallestAngle;
	}

	public void setPrintNumberOfSmallAngles(boolean printNumberOfSmallAngles) {
		this.printNumberOfSmallAngles = printNumberOfSmallAngles;
	}
	
	public void setSmallAngleTolerance(double smallAngleTolerance) {
		this.smallAngleTolerance = smallAngleTolerance;
	}
	
	public void setPrintShortestEdge(boolean printShortestEdge) {
		this.printShortestEdge = printShortestEdge;
	}
	
	public void setPrintNumberOfShortEdges(boolean printNumberOfShortEdges) {
		this.printNumberOfShortEdges = printNumberOfShortEdges;
	}
	
	public void setShortEdgesTolerance(double shortEdgesTolerance) {
		this.shortEdgesTolerance = shortEdgesTolerance;
	}
	
	public void setPrintVolume(boolean printVolume) {
		this.printVolume = printVolume;
	}
	
	public void setPrintNumberOfFacesAndVertices(boolean printNumberOfFacesAndVertices) {
		this.printNumberOfFacesAndVertices = printNumberOfFacesAndVertices;
	}	
	
	public boolean isPrintBuildingInfo() {
		return printBuildingInfo;
	}
	
	public boolean isPrintStatus() {
		return printStatus;
	}

	public boolean isPrintSmallestAngle() {
		return printSmallestAngle;
	}
	
	public boolean isPrintNumberOfSmallAngles() {
		return printNumberOfSmallAngles;
	}
	
	public double getSmallAngleTolerance() {
		return smallAngleTolerance;
	}
	
	public boolean isPrintShortestEdge() {
		return printShortestEdge;
	}
	
	public boolean isPrintNumberOfShortEdges() {
		return printNumberOfShortEdges;
	}
	
	public double getShortEdgesTolerance() {
		return shortEdgesTolerance;
	}
	
	public boolean isPrintVolume() {
		return printVolume;
	}	
	
	public boolean isPrintNumberOfFacesAndVertices() {
		return printNumberOfFacesAndVertices;
	}	
	
}
